[![Build Status](https://travis-ci.org/SpikeInterface/spikesorters.svg?branch=master)](https://travis-ci.org/SpikeInterface/spikesorters) [![PyPI version](https://badge.fury.io/py/spikesorters.svg)](https://badge.fury.io/py/spikesorters)

# SpikeSorters
Collection of spike sorter wrappers for use in [spiketoolkit](https://github.com/SpikeInterface/spiketoolkit), [spikeforest](https://github.com/flatironinstitute/spikeforest), and elsewhere.
